==> alg-common-1.22.1-20191009.085457-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivityInfoModel.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

public class ActivityInfoModel {
    long activityId;
    long slotId;
    long appId;
    double changeScore;
    Val hisRequest = new Val();
    Val hisClick = new Val();
    Val hisSend;
    Val hisCost = new Val();
    Val lastRequest;
    Val lastClick;
    Val lastSend;
    Val lastCost;
    ActivityChangeVal activityChangeVal;
    int activityTypeNew; //v3.5  新老活动类型 0 新创建活动，;1 新活动;2 老活动;
    boolean isHot; //热点活动， true：热点活动，false：普通活动
    long uploadTime; //活动上架时间，微秒
    int subType = 0; //v4.0 皮肤含有ops或vm新活动 1;否则老活动 0
    boolean isExcellent = false; //v4.0 是否是优质活动
    double nPvClick; //v4.0 归一化每pv券点击
    double nPvCost; //v4.0 归一化每pv消耗
    double nCvrForm; //v4.0 归一化表单类cvr
    double nCvrNotForm; //v4.0 归一化非表单类cvr
    double nCvr; // v4.0 归一化转化率
    double score; //4.0 归一化得分

    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public Val getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(Val hisRequest) {
        this.hisRequest = hisRequest;
    }

    public Val getHisClick() {
        return hisClick;
    }

    public void setHisClick(Val hisClick) {
        this.hisClick = hisClick;
    }

    public Val getHisSend() {
        return hisSend;
    }

    public void setHisSend(Val hisSend) {
        this.hisSend = hisSend;
    }

    public Val getHisCost() {
        return hisCost;
    }

    public void setHisCost(Val hisCost) {
        this.hisCost = hisCost;
    }

    public Val getLastRequest() {
        return lastRequest;
    }

    public void setLastRequest(Val lastRequest) {
        this.lastRequest = lastRequest;
    }

    public Val getLastClick() {
        return lastClick;
    }

    public void setLastClick(Val lastClick) {
        this.lastClick = lastClick;
    }

    public Val getLastSend() {
        return lastSend;
    }

    public void setLastSend(Val lastSend) {
        this.lastSend = lastSend;
    }

    public Val getLastCost() {
        return lastCost;
    }

    public void setLastCost(Val lastCost) {
        this.lastCost = lastCost;
    }

    public ActivityChangeVal getActivityChangeVal() {
        return activityChangeVal;
    }

    public void setActivityChangeVal(ActivityChangeVal activityChangeVal) {
        this.activityChangeVal = activityChangeVal;
    }

    public int getActivityTypeNew() {
        return activityTypeNew;
    }

    public void setActivityTypeNew(int activityTypeNew) {
        this.activityTypeNew = activityTypeNew;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(long uploadTime) {
        this.uploadTime = uploadTime;
    }

    public int getSubType() {
        return subType;
    }

    public void setSubType(int subType) {
        this.subType = subType;
    }

    public boolean isExcellent() {
        return isExcellent;
    }

    public void setExcellent(boolean excellent) {
        isExcellent = excellent;
    }

    public double getnPvClick() {
        return nPvClick;
    }

    public void setnPvClick(double nPvClick) {
        this.nPvClick = nPvClick;
    }

    public double getnPvCost() {
        return nPvCost;
    }

    public void setnPvCost(double nPvCost) {
        this.nPvCost = nPvCost;
    }

    public double getnCvrForm() {
        return nCvrForm;
    }

    public void setnCvrForm(double nCvrForm) {
        this.nCvrForm = nCvrForm;
    }

    public double getnCvrNotForm() {
        return nCvrNotForm;
    }

    public void setnCvrNotForm(double nCvrNotForm) {
        this.nCvrNotForm = nCvrNotForm;
    }

    public double getnCvr() {
        return nCvr;
    }

    public void setnCvr(double nCvr) {
        this.nCvr = nCvr;
    }

    public double getScore() {
        return score;
    }

    public void setScore(double score) {
        this.score = score;
    }
}

==> alg-common-2.5.11-20190908.083126-1-sources.jar: cn/com/duiba/nezha/alg/common/model/activityselectconversionforms/ActivityInfoModel.java <==
package cn.com.duiba.nezha.alg.common.model.activityselectconversionforms;

public class ActivityInfoModel {
    long activityId;
    long slotId;
    long appId;
    double changeScore;
    Val hisRequest;
    Val hisClick;
    Val hisSend;
    Val hisCost;
    Val lastRequest;
    Val lastClick;
    Val lastSend;
    Val lastCost;
    ActivityChangeVal activityChangeVal;
    int activityTypeNew; //v3.5  新老活动类型 0 新创建活动，;1 新活动;2 老活动;
    boolean isHot; //热点活动， true：热点活动，false：普通活动
    long uploadTime; //活动上架时间，微秒

    public ActivityChangeVal getActivityChangeVal() {
        return activityChangeVal;
    }

    public void setActivityChangeVal(ActivityChangeVal activityChangeVal) {
        this.activityChangeVal = activityChangeVal;
    }



    public long getActivityId() {
        return activityId;
    }

    public void setActivityId(long activityId) {
        this.activityId = activityId;
    }

    public long getSlotId() {
        return slotId;
    }

    public void setSlotId(long slotId) {
        this.slotId = slotId;
    }

    public long getAppId() {
        return appId;
    }

    public void setAppId(long appId) {
        this.appId = appId;
    }

    public double getChangeScore() {
        return changeScore;
    }

    public void setChangeScore(double changeScore) {
        this.changeScore = changeScore;
    }

    public Val getHisRequest() {
        return hisRequest;
    }

    public void setHisRequest(Val hisRequest) {
        this.hisRequest = hisRequest;
    }

    public Val getHisClick() {
        return hisClick;
    }

    public void setHisClick(Val hisClick) {
        this.hisClick = hisClick;
    }

    public Val getHisSend() {
        return hisSend;
    }

    public void setHisSend(Val hisSend) {
        this.hisSend = hisSend;
    }

    public Val getHisCost() {
        return hisCost;
    }

    public void setHisCost(Val hisCost) {
        this.hisCost = hisCost;
    }

    public Val getLastRequest() {
        return lastRequest;
    }

    public void setLastRequest(Val lastRequest) {
        this.lastRequest = lastRequest;
    }

    public Val getLastClick() {
        return lastClick;
    }

    public void setLastClick(Val lastClick) {
        this.lastClick = lastClick;
    }

    public Val getLastSend() {
        return lastSend;
    }

    public void setLastSend(Val lastSend) {
        this.lastSend = lastSend;
    }

    public Val getLastCost() {
        return lastCost;
    }

    public void setLastCost(Val lastCost) {
        this.lastCost = lastCost;
    }

    public int getActivityTypeNew() {
        return activityTypeNew;
    }

    public void setActivityTypeNew(int activityTypeNew) {
        this.activityTypeNew = activityTypeNew;
    }

    public boolean isHot() {
        return isHot;
    }

    public void setHot(boolean hot) {
        isHot = hot;
    }

    public long getUploadTime() {
        return uploadTime;
    }

    public void setUploadTime(long uploadTime) {
        this.uploadTime = uploadTime;
    }
}
